% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/odds.ratio.R
\name{odds.ratio}
\alias{odds.ratio}
\title{Odds ratio of single or collapsed variants}
\usage{
odds.ratio(data, y, collapse = FALSE)
}
\arguments{
\item{data}{a data frame or numeric matrix, usually a gene. Genotypes should be coded as 0,1 or 2.}

\item{y}{a numeric vector with two levels. Phenotype values are coded as 0 or 1.}

\item{collapse}{a logical value indicating whether or not to calculate odds ratio of each single variant. Default = \code{FALSE} for single variant calculation, or \code{TRUE} for collapsed variants calculation.}
}
\description{
This function simply calculates either odds ratio of each single variant or odds ratio of collapsed variants within input data.
}
\details{
When \code{"collapse"} is true, a regional odds ratio will be used to represent the overall effect size and direction of variants within a genomic region. It is calculated by summing up all the allele counts to form a new contingency table, and then calcuating the regional odds ratio from the combined contingency table.
}
\examples{
data(fuzzy.zfa.example)
attach(fuzzy.zfa.example)

# Single variant calculation
ORSingle<-odds.ratio(Z,y,collapse=FALSE)

# Collapsed variants calculation
ORCollapse<-odds.ratio(Z,y,collapse=TRUE)

}
\seealso{
\code{\link{fuzzy.zfa}}, \code{\link{test.variants}}, \code{\link{zfa.plot}}
}
