% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zfa.plot.R
\name{zfa.plot}
\alias{zfa.plot}
\title{OR plot for graphical visualization of fuzzy ZFA optimized region}
\usage{
zfa.plot(
  singleVariantResult,
  zfaResult,
  geneName = NULL,
  bpInfo = NULL,
  chr = NULL,
  ...
)
}
\arguments{
\item{singleVariantResult}{results of single variant test, a data frame with three variables: pos, pvalue and OR. The results could be directly obtained from \code{"test.variants"} function.}

\item{zfaResult}{results of fuzzy ZFA optimization, the output of \code{"fuzzy.zfa"} function.}

\item{geneName}{Gene name or symbol of the region, if any. Default = NULL.}

\item{bpInfo}{a vector of bp information for each variant, if any. Default = NULL.}

\item{chr}{a number or character indicating which chromosome the region belongs to, if any. Default = NULL.}

\item{...}{graphical parameters.}
}
\description{
This function visualizes the results of optimized region by OR plot in real data analysis. It returns standard ggplot object, upon which the user can add other geoms.
}
\details{
The OR plot is designed to gain more biological insights by graphical visualization for the optimized region after applying fuzzy ZFA.

The x axis represents the array and corresponding chromosome position, and the y axis denotes the log transform of odds ratio. Red lines indicate variants of increased risk of disease, while green lines suggest variants with protective effect.

The pink bubbles define the p-value of each rare variant, a smaller p-value gives a larger scale. The optimized region is highlighted with labels of both regional odds ratio and p-value.
}
\examples{
data(fuzzy.zfa.example)
attach(fuzzy.zfa.example)

# Generate single variant results by wtest
result1<-test.variants(Z,y,collapse=FALSE,test = "wtest")

# Generate zfa optimization results by wtest
result2<-fuzzy.zfa(Z,y,fast.path = TRUE,filter.pval=0.01,test = "wtest")

# Visualize the optimization results by OR plot
OR.plot<-zfa.plot(singleVariantResult=result1,zfaResult=result2)
plot(OR.plot)

}
\seealso{
\code{\link{fuzzy.zfa}}, \code{\link{test.variants}}, \code{\link{odds.ratio}}
}
