#' @import parallel
#' @importFrom S4Vectors as.matrix

fuzzyZFA.SKAT.zoom.mmulthread <- function(data,y,boundResult,test,obj,filter.pval,zoom.pval){
  myidx <- parallel::splitIndices(nrow(boundResult),myinfo$nwrkrs)[[myinfo$id]]
  for(i in myidx){
    #zoom
    if (test=="SKAT") {
      zoom.pval[i]<-SKAT::SKATBinary(data[,c(boundResult[i,1]:boundResult[i,2])],obj)$p.value*boundResult[i,3]
    } else if (test=="SKATO") {
      zoom.pval[i]<-SKAT::SKATBinary(data[,c(boundResult[i,1]:boundResult[i,2])],obj,method="SKATO")$p.value*boundResult[i,3]
    } else if (test=="burden") {
      zoom.pval[i]<-SKAT::SKATBinary(data[,c(boundResult[i,1]:boundResult[i,2])],obj,method="Burden")$p.value*boundResult[i,3]
    }
    zoom.pval[i] <- ifelse(zoom.pval[i]>1,1,zoom.pval[i])
  }
}

fuzzyZFA.SKAT.zoom <- function(boundResult,data, y, test,fast.path,filter.pval,thd_num){
  obj<-SKAT::SKAT_Null_Model(y ~ 1, out_type="D")
  if(fast.path){
    zoomResult<-fast.zoom(data,y,obj,test)
    return(zoomResult)
  }
  cls = makeCluster(thd_num)
  on.exit(stopCluster(cls))
  mgrinit(cls)
  mgrmakevar(cls,"data_share",dim(data)[1],dim(data)[2])
  mgrmakevar(cls,"y_share",dim(data)[1],1)
  mgrmakevar(cls,"boundResult_share",dim(boundResult)[1],dim(boundResult)[2])
  mgrmakevar(cls,"zoom.pval",dim(boundResult)[1],1)
  data_share[,] <- data
  y_share[,] <- y
  boundResult_share[,] <- boundResult
  zoom.pval[,] <- 1
  clusterExport(cls,"fuzzyZFA.SKAT.zoom.mmulthread",envir = environment())
  clusterExport(cls,list("obj","test","filter.pval"),envir = environment())
  clusterEvalQ(cls,fuzzyZFA.SKAT.zoom.mmulthread(data_share,y_share,boundResult_share,test,obj,filter.pval,zoom.pval))
  zoom.pval <- S4Vectors::as.matrix(zoom.pval)
  min_zoom_pval <- which.min(zoom.pval)
  ZoomResult <- t(c(boundResult[min_zoom_pval,],zoom.pval[min_zoom_pval]))
  colnames(ZoomResult) <- c("lb", "ub", "nr", "corrected.pvalue")
  return(ZoomResult)
}

fast.zoom<-function(data,y,obj,test) {
  lower<-1
  upper<-ncol(data)
  mid<-ncol(data)
  if (test=="SKAT") {
    pvalue<-SKAT::SKATBinary(as.matrix(data[,c(lower:upper)]),obj)$p.value
  } else if (test=="SKATO") {
    pvalue<-SKAT::SKATBinary(as.matrix(data[,c(lower:upper)]),obj,method="SKATO")$p.value
  } else if (test=="burden") {
    pvalue<-SKAT::SKATBinary(as.matrix(data[,c(lower:upper)]),obj,method="Burden")$p.value
  }
  pvalue.all<-pvalue
  upper.all<-upper
  lower.all<-lower
  while (mid>3){
    mid<-mid/2
    if (test=="SKAT") {
      pvalue.left<-(SKAT::SKATBinary(as.matrix(data[,c(lower:floor(lower+mid-1))]),obj)$p.value)
      pvalue.right<-(SKAT::SKATBinary(as.matrix(data[,c(floor(upper-mid+1):upper)]),obj)$p.value)
    } else if (test=="SKATO") {
      pvalue.left<-(SKAT::SKATBinary(as.matrix(data[,c(lower:floor(lower+mid-1))]),obj,method="SKATO")$p.value)
      pvalue.right<-(SKAT::SKATBinary(as.matrix(data[,c(floor(upper-mid+1):upper)]),obj,method="SKATO")$p.value)
    } else if (test=="burden") {
      pvalue.left<-(SKAT::SKATBinary(as.matrix(data[,c(lower:floor(lower+mid-1))]),obj,method="Burden")$p.value)
      pvalue.right<-(SKAT::SKATBinary(as.matrix(data[,c(floor(upper-mid+1):upper)]),obj,method="Burden")$p.value)
    }
    pvalue<-min(pvalue.left,pvalue.right)
    if (pvalue==pvalue.left){
      upper<-floor(upper-mid)
    } else if (pvalue==pvalue.right){
      lower<-floor(lower+mid)
    }
    mid<-upper-lower+1
    pvalue<-ifelse(pvalue>1,1,pvalue)
    pvalue.all<-c(pvalue.all,pvalue)
    upper.all<-c(upper.all,upper)
    lower.all<-c(lower.all,lower)
  }
  pvalue.final<-min(pvalue.all)
  upper.final<-upper.all[which(pvalue.all==pvalue.final)[1]]
  lower.final<-lower.all[which(pvalue.all==pvalue.final)[1]]
  pvalue.final<-pvalue.final
  pvalue.final<-ifelse(pvalue.final>1,1,pvalue.final)
  result<-cbind(lower.final,upper.final,pvalue.final)
  colnames(result)<-c("lb","ub","corrected.pvalue")
  return(result)
}

fuzzyZFA.SKAT.focus.left.mmulthread <- function(data,y,ZoomResult,inward,outward,test,obj,pvalue.left,lb.all){
  myidx <- parallel::splitIndices(inward+outward+1,myinfo$nwrkrs)[[myinfo$id]]
  for(i in myidx){
    if ((ZoomResult[,"lb"]+i-outward-1)>0) {
      if (test=="SKAT") {
        pvalue.left[i]<-SKAT::SKATBinary(as.matrix(data[,c((ZoomResult[,"lb"]+i-outward-1):ZoomResult[,"ub"])]),obj)$p.value
      } else if (test=="SKATO") {
        pvalue.left[i]<-SKAT::SKATBinary(as.matrix(data[,c((ZoomResult[,"lb"]+i-outward-1):ZoomResult[,"ub"])]),obj,method="SKATO")$p.value
      } else if (test=="burden") {
        pvalue.left[i]<-SKAT::SKATBinary(as.matrix(data[,c((ZoomResult[,"lb"]+i-outward-1):ZoomResult[,"ub"])]),obj,method="Burden")$p.value
      }
      lb.all[i] <- ZoomResult[,"lb"]+i-outward-1
    }
  }
}   

fuzzyZFA.SKAT.focus.right.mmulthread <- function(data,y,ZoomResult,inward,outward,test,obj,lb.final,pvalue.right,ub.all){
  myidx <- parallel::splitIndices(inward+outward+1,myinfo$nwrkrs)[[myinfo$id]]
  for(i in myidx){
    if ((ZoomResult[,"ub"]+i-inward-1)<(ncol(data)+1)) {
      if (test=="SKAT") {
        pvalue.right[i]<-SKAT::SKATBinary(as.matrix(data[,c(lb.final:(ZoomResult[,"ub"]+i-inward-1))]),obj)$p.value
      } else if (test=="SKATO") {
        pvalue.right[i]<-SKAT::SKATBinary(as.matrix(data[,c(lb.final:(ZoomResult[,"ub"]+i-inward-1))]),obj,method="SKATO")$p.value
      } else if (test=="burden") {
        pvalue.right[i]<-SKAT::SKATBinary(as.matrix(data[,c(lb.final:(ZoomResult[,"ub"]+i-inward-1))]),obj,method="Burden")$p.value
      }
      ub.all[i] <- ZoomResult[,"ub"]+i-inward-1
    }
  }
} 


### fuzzy zfa

fuzzy.ZFA.SKAT <- function(boundResult,data, y, obj, test,fast.path,filter.pval,thd_num){
  # zoom
  if(fast.path){
    ZoomResult<-fast.zoom(data,y,obj,test)
  }else{
    cls = makeCluster(thd_num)
    on.exit(stopCluster(cls))
    mgrinit(cls)
    mgrmakevar(cls,"data_share",dim(data)[1],dim(data)[2])
    mgrmakevar(cls,"y_share",dim(data)[1],1)
    mgrmakevar(cls,"boundResult_share",dim(boundResult)[1],dim(boundResult)[2])
    mgrmakevar(cls,"zoom.pval",dim(boundResult)[1],1)
    data_share[,] <- data
    y_share[,] <- y
    boundResult_share[,] <- boundResult
    zoom.pval[,] <- 1
    clusterExport(cls,"fuzzyZFA.SKAT.zoom.mmulthread",envir = environment())
    clusterExport(cls,list("obj","test","filter.pval"),envir = environment())
    clusterEvalQ(cls,fuzzyZFA.SKAT.zoom.mmulthread(data_share,y_share,boundResult_share,test,obj,filter.pval,zoom.pval))
    zoom.pval <- S4Vectors::as.matrix(zoom.pval)
    min_zoom_pval <- which.min(zoom.pval)
    ZoomResult <- t(c(boundResult[min_zoom_pval,],zoom.pval[min_zoom_pval]))
    colnames(ZoomResult) <- c("lb", "ub", "nr", "corrected.pvalue")
  }
  # focus
  filter.pval<-ifelse(is.null(filter.pval),1,filter.pval)
  bin<-ncol(data)
  m <- nrow(boundResult)
  steps <- 0
  if (ZoomResult[,"ub"]-ZoomResult[,"lb"]+1==bin) {
    if(fast.path){
      resultFinal<-t(c(1,bin,bin,ZoomResult[,"corrected.pvalue"],bin/2+log2(bin)-1))
    }else{
      resultFinal<-t(c(1,bin,bin,ZoomResult[,"corrected.pvalue"],m))
    }
    return(resultFinal)
  }
  if (ZoomResult[,"corrected.pvalue"]<=filter.pval){
    d<-ZoomResult[,"ub"]-ZoomResult[,"lb"]+1 
    if (d==2) {
      inward<-0
      outward<-2*d
    } else {
      inward<-floor(d/4)
      outward<-floor(d/2)
    }
    cls = makeCluster(thd_num)
    on.exit(stopCluster(cls))
    mgrinit(cls)
    mgrmakevar(cls,"data_share",dim(data)[1],dim(data)[2])
    mgrmakevar(cls,"y_share",dim(data)[1],1)
    data_share[,] <- data
    y_share[,] <- y
    ### left
    mgrmakevar(cls,"pvalue.left",inward+outward+1,1)
    mgrmakevar(cls,"lb.all",inward+outward+1,1)
    pvalue.left[,] <- 2
    lb.all[,] <- -1
    clusterExport(cls,"fuzzyZFA.SKAT.focus.left.mmulthread",envir = environment())
    clusterExport(cls,list("obj","test","ZoomResult","inward","outward"),envir = environment())
    clusterEvalQ(cls,fuzzyZFA.SKAT.focus.left.mmulthread(data_share,y_share,ZoomResult,inward,outward,test,obj,pvalue.left,lb.all))
    pvalue.left <- S4Vectors::as.matrix(pvalue.left)
    lb.all <- S4Vectors::as.matrix(lb.all)
    lb.final<-lb.all[which(pvalue.left==min(pvalue.left))][1]
    ### right
    mgrmakevar(cls,"pvalue.right",inward+outward+1,1)
    mgrmakevar(cls,"ub.all",inward+outward+1,1)
    pvalue.right[,] <- 2
    ub.all[,] <- -1
    clusterExport(cls,"fuzzyZFA.SKAT.focus.right.mmulthread",envir = environment())
    clusterExport(cls,list("lb.final"),envir = environment())
    clusterEvalQ(cls,fuzzyZFA.SKAT.focus.right.mmulthread(data_share,y_share,ZoomResult,inward,outward,test,obj,lb.final,pvalue.right,ub.all))
    pvalue.right <- S4Vectors::as.matrix(pvalue.right)
    ub.all <- S4Vectors::as.matrix(ub.all)
    pvalue.final <- min(pvalue.right)
    ub.final<-ub.all[which(pvalue.right==pvalue.final)][1]
    k <- length(which(lb.all!=-1))+length(which(ub.all!=-1))-2
    if (fast.path) {
      pvalue.right.corrected<-pvalue.final*(bin/2+log2(bin)-1+k)
      steps <- (bin/2+log2(bin)-1+k)
    } else {
      pvalue.right.corrected<-pvalue.final*(m+k)
      steps <- (m+k)
    }
    pvalue.right.corrected<-ifelse(pvalue.right.corrected>1,1,pvalue.right.corrected)
    result.final<-cbind(lb.final,ub.final,ub.final-lb.final+1,pvalue.right.corrected,steps)
  } else {
    if (fast.path) {
      ZoomResult[,"corrected.pvalue"]<-ZoomResult[,"corrected.pvalue"]*(bin/2+log2(bin)-1)
      ZoomResult[,"corrected.pvalue"]<-ifelse(ZoomResult[,"corrected.pvalue"]>1,1,ZoomResult[,"corrected.pvalue"])
      steps <- (bin/2+log2(bin)-1)
    } else {
      ZoomResult[,"corrected.pvalue"]<-ZoomResult[,"corrected.pvalue"]/(ZoomResult[,"nr"])*m
      ZoomResult[,"corrected.pvalue"]<-ifelse(ZoomResult[,"corrected.pvalue"]>1,1,ZoomResult[,"corrected.pvalue"])
      steps <- (ZoomResult[,"nr"])*m
    }
    result.final<-t(c(ZoomResult[,"lb"],ZoomResult[,"ub"],ZoomResult[,"ub"]-ZoomResult[,"lb"]+1,ZoomResult[,"corrected.pvalue"],steps))
  }
  return(result.final)
}
