% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fuzzyZFA.R
\name{fuzzy.zfa}
\alias{fuzzy.zfa}
\title{Fuzzy Zoom-Focus Algorithm}
\usage{
fuzzy.zfa(
  data,
  y,
  fast.path = TRUE,
  filter.pval = 0.001,
  test = c("SKAT", "SKATO", "burden", "wtest"),
  cores = 1
)
}
\arguments{
\item{data}{a data frame or numeric matrix, usually a gene. Genotypes should be coded as 0,1 or 2.}

\item{y}{a numeric vector with two levels. Phenotype values are coded as 0 or 1.}

\item{fast.path}{a logical value indicating whether or not to use the fast-Zoom approach. The fast-Zoom performs a binary search instead of exhaustive search, such that at each partition order, the region is divided into two parts, only the part with smaller p-value is continued for the next level search. Default = TRUE.}

\item{filter.pval}{a p-value threshold to select zoomed region for conducting focusing step. When specified, only zoomed region with p-value smaller than the threshold will be passed to focusing step. Default=0.01. Set filter.pval=NULL for conducting focusing step in any case.}

\item{test}{a character to choose the rare variant method that combines with the fuzzy Zoom-Focus Algorithm.If test = "SKAT", the SKAT of variance component test is applied. If test = "SKATO", the SKAT-O of combination method test is applied. If test = "burden", the weighted burden test is applied. If test = "wtest", the W-test of burden test category is applied.}

\item{cores}{a numeric integer indicating the number of cores to run in parallel. You can easily check the number of CPU cores on the current machine by calling detectCores() function in the parallel package.}
}
\value{
The \code{"fuzzy.zfa"} function returns a table with following components:

\item{lower.bound}{Lower bound of the optimized region}

\item{upper.bound}{Upper bound of the optimized region}

\item{opt.region.size}{Optimized region size}

\item{odds.ratio}{Regional odds ratio of collapsed variants within optimal region, see \code{\link{odds.ratio}} for more details}

\item{corrected.pvalue}{Bonferroni corrected p-value of optimal region}

\item{steps}{Total number of tests in ZFA.}

Note that fuzzy ZFA assumes that the input variants are arranged by chromosome positions, such as a functional gene. If variants from non-adjacent genomic regions are input as one data, the zfa will still treat them as adjacent. In this case, the user should be careful in interpreting the results: when an optimized region consists of distant variants, the region may not be biologically meaningful.
}
\description{
The function automatically locates the optimal testing region of desired rare variant method, which requires both genotype and phenotype data as input. It is applicable to exome sequenced genes with vare variants, which calls existing rare variant method functions to conduct rare variant association test.

The fuzzy Zoom-Focus algorithm (ZFA) takes two main steps, fuzzy Zooming and Focusing, to search for an optimal testing region of a given gene of any size. Given a genomic region (e.g. a gene or functional unit) of arbitrary size, the fuzzy Zooming step first performs a global search within the gene to locate an optimal zoomed region among all fuzzy partitons at different orders. The boundaries of the zoomed region are then refined in the next step Focusing by by extending both lower and upper bound.
}
\details{
The algorithm automatically selects an optimized testing region within a given gene, which enables convenient combination of various rare variant methods and, yields power improvement. Current version includes 4 existing rare variant tests. The SKAT, SKAT-O and burden test are called from \code{'SKAT'} package, and the W-test Collapsing method is self-contained.
}
\examples{
data(fuzzy.zfa.example)
attach(fuzzy.zfa.example)

## fast-zoom with wtest, then pass zoomed region to focusing step, 
## and output optimization results
zfa.result1<-fuzzy.zfa(Z,y,fast.path = TRUE,
                     filter.pval=NULL,test = "wtest",cores=1)

## fuzzy zooming with wtest, only if zoomed region has p-value<0.01 will 
## be passed to focusing step
zfa.result2<-fuzzy.zfa(Z,y,fast.path = TRUE,
                     filter.pval=0.01,test = "wtest",cores=1)

}
\references{
M. H. Wang., H. Weng., et al. (2017) A Zoom-Focus algorithm (ZFA) to locate the optimal testing region for rare variant association tests. Bioinformatics.

M. H. Wang., R. Sun., et al. (2016) A fast and powerful W-test for pairwise epistasis testing. Nucleic Acids Research.doi:10.1093/nar/gkw347.

R. Sun., H. Weng., et al. (2016) A W-test collapsing method for rare-variant association testing in exome sequencing data. Genetic Epidemiology, 40(7): 591-596.

Wu, M. C., Lee, S., et al. (2011) Rare Variant Association Testing for Sequencing Data Using the Sequence Kernel Association Test (SKAT). American Journal of Human Genetics, 89, 82-93.

Lee, S., Emond, M.J., et al. (2012) Optimal unified approach for rare variant association testing with application to small sample case-control whole-exome sequencing studies. American Journal of Human Genetics, 91, 224-237.

Lee, S., Fuchsberger, C., et al. (2015) An efficient resampling method for calibrating single and gene-based rare variant association analysis in case-control studies. Biostatistics, kxv033.
}
\seealso{
\code{\link{test.variants}}, \code{\link{odds.ratio}}, \code{\link{zfa.plot}}
}
\author{
Yexian Zhang, Fengfeng Zhou, Haoyi Weng and Maggie Wang
}
