#include <RcppArmadillo.h>
// [[Rcpp::depends(RcppArmadillo)]]
using namespace Rcpp;
using namespace arma;
#include <cmath>
#include <omp.h>

// [[Rcpp::export]]
double wtest_zfa2(arma::mat& a,arma::rowvec& b,int lower_idx,int upper_idx){
  // int cols = a.n_cols;
  int rows = a.n_rows;
  mat all_table=zeros(6,(upper_idx-lower_idx+1));
  for(int i=lower_idx,idx=0;i<=upper_idx;i++,idx++){
    int index=0;
    for(int j=0;j<rows;j++){
      index = int(a(j,i)) + b(j)*3;
      all_table(index,idx) +=1;
    }
  }
  mat sum_table = sum(all_table,1);
  sum_table.reshape(3,2);
  colvec T = sum(sum_table,1);
  mat cont_table=sum_table.rows(find(T!=0));
  if(cont_table.min()==0){
    cont_table+=0.5;
  }
  mat hf={{0.5,1},{0.667,2}};
  // x2
  int df = cont_table.n_rows-2;//下标从0开始
  mat o = cont_table;
  rowvec colSum = sum(cont_table,0);
  for(unsigned int i =0;i<cont_table.n_cols;i++)
    cont_table.col(i) /= colSum(i);
  mat p = cont_table/(1-cont_table);
  vec OR = p.col(1)/p.col(0);
  rowvec s= sum(o,0);
  o.resize(o.n_rows,4);
  o.col(2)=s(0)-o.col(0);
  o.col(3)=s(1)-o.col(1);
  vec sd=sqrt(sum((1/o),1));
  double x2_value =sum(square(log(OR)/sd));
  double w_value = x2_value*hf(df,0);
  double p_value = R::pchisq(w_value,hf(df,1),0,0);//yxzhang
  return p_value;
}

// [[Rcpp::export]]
arma::rowvec fuzzy_zoom_fast(arma::mat& data, arma::rowvec& y,arma::mat& bound_index,int idx){
  int cols=bound_index(idx,1)-bound_index(idx,0)+1;
  int lower=bound_index(idx,0);
  int upper=bound_index(idx,1);
  float mid=(float)cols;
  int len=std::floor(log2(cols));
  std::vector<int> lower_all(len);
  std::vector<int> upper_all(len);
  std::vector<double> p_val(len);
  std::vector<double> p_val_left_right(2);
  p_val[0]=wtest_zfa2(data,y,lower-1,upper-1);
  lower_all[0]=lower;
  upper_all[0]=upper;
  int count=1;
  while(mid>3){
    mid=mid/2.0;
    p_val_left_right[0]=wtest_zfa2(data,y,lower-1,(int)(lower+mid-2));
    p_val_left_right[1]=wtest_zfa2(data,y,(int)(upper-mid),upper-1);
    if(p_val_left_right[0]<=p_val_left_right[1]){
      upper=(int)(upper-mid);
      p_val[count]=p_val_left_right[0];
    }else{
      lower=(int)(lower+mid);
      p_val[count]=p_val_left_right[1];
    }
    mid=(float)(upper-lower+1);
    lower_all[count]=lower;
    upper_all[count]=upper;
    count++;
  }
  int min_p_val_idx = std::min_element(p_val.begin(),p_val.end()) - p_val.begin();
  double p_val_corr=(p_val[min_p_val_idx]>1)?1:p_val[min_p_val_idx];
  arma::rowvec result_final ={(double)lower_all[min_p_val_idx], (double)upper_all[min_p_val_idx], p_val_corr};
  return(result_final);
}

// [[Rcpp::export]]
arma::rowvec full_zoom(arma::mat& data, arma::rowvec& y,arma::mat& bound_index,int thd_num=1){
  int rows=bound_index.n_rows;
  arma::mat result(rows,1);
#pragma omp parallel for num_threads(thd_num)
  for(int i=0; i<rows;i++){
    result(i)=wtest_zfa2(data,y,bound_index(i,0)-1,bound_index(i,1)-1)*bound_index(i,2);
  }
  result=join_rows(bound_index,result);
  return(result.row(result.col(3).index_min()));
}

// [[Rcpp::export]]
arma::rowvec focusing_fuzzy(arma::mat& data,arma::rowvec& y,arma::rowvec ZoomResult,int m,bool fast_path,double filter_pval,int thd_num=1){
  filter_pval=(filter_pval>1)?1:filter_pval;
  int bin=data.n_cols;
  arma::rowvec result_final(5);
  int d=(int)(ZoomResult[1]-ZoomResult[0]+1);
  if(d==(int)data.n_cols){
    result_final ={1, (double)bin, (double)bin,ZoomResult[3],(double)m};
    return(result_final);
  }
  int inward;
  int outward;
  double steps=0.0;
  if(ZoomResult[3]<=filter_pval){
    if(d==2){
      inward=0;
      outward=2*d;
    }else{
      inward=std::floor(d/4);
      outward=std::floor(d/2);
    }
    std::vector<double> p_val(inward+outward+1,2.0);
    std::vector<int> idx(inward+outward+1,-1);
    int count=0;
#pragma omp parallel for num_threads(thd_num)
    for(int i=(-outward);i<=inward;i++){
      if((ZoomResult[0]+i)>0){
        p_val[outward+i]=wtest_zfa2(data,y,(int)(ZoomResult[0]+i-1),(int)(ZoomResult[1]-1));
        idx[outward+i]=(int)(ZoomResult[0]+i-1);
#pragma omp critical
{
  count++;
}
      }
    }
    int min_idx = std::min_element(p_val.begin(),p_val.end()) - p_val.begin();
    std::vector<double> p_val2(inward+outward+1,2.0);
    std::vector<int> idx2(inward+outward+1,-1);
    int count2=0;
    // int cols=data.n_cols;
#pragma omp parallel for num_threads(thd_num)
    for(int i=(-inward);i<=outward;i++){
      if((ZoomResult[1]+i)< bin+1){
        p_val2[inward+i]=wtest_zfa2(data,y,idx[min_idx],(int)(ZoomResult[1]+i-1));
        idx2[inward+i]=(int)(ZoomResult[1]+i-1);
#pragma omp critical
{
  count2++;
}
      }
    }
    int min_idx2 = std::min_element(p_val2.begin(),p_val2.end()) - p_val2.begin();
    int k=count + count2-2;
    double pvalue_right_corrected;
    if(fast_path){
      pvalue_right_corrected=p_val2[min_idx2]*(bin/2.0+std::log2(bin)-1+k);
      steps=(bin/2.0+std::log2(bin)-1+k);
    }else{
      pvalue_right_corrected=p_val2[min_idx2]*(m+k);
      steps=(m+k);
    }
    pvalue_right_corrected=(pvalue_right_corrected>1)?1:pvalue_right_corrected;
    double lower_bound=idx[min_idx]+1;
    double upper_bound=idx2[min_idx2]+1;
    double region_size=idx2[min_idx2]-idx[min_idx]+1;
    result_final ={lower_bound, upper_bound, region_size,pvalue_right_corrected,steps};
  } else{
    if(fast_path){
      ZoomResult[3]=ZoomResult[3]*(bin/2.0+std::log2(bin)-1);
      ZoomResult[3]=(ZoomResult[3]>1)?1:ZoomResult[3];
      steps=(bin/2.0+std::log2(bin)-1);
    }else{
      ZoomResult[3]=ZoomResult[3]/ZoomResult[2]*m;
      ZoomResult[3]=(ZoomResult[3]>1)?1:ZoomResult[3];
      steps=ZoomResult[2]*m;
    }
    double region_size=ZoomResult[1]-ZoomResult[0]+1;
    result_final ={ZoomResult[0], ZoomResult[1], region_size,ZoomResult[3],steps};
  }
  return(result_final);
}

// [[Rcpp::export]]
arma::mat zoom_focuse_fuzzy(arma::mat& bound_index,arma::mat& data, arma::rowvec& y, bool fast_path,double filter_pval,int thd_num=1){
  filter_pval=(filter_pval>1)?1:filter_pval;
  arma::rowvec zoom_result(3);
  // zooming
  if(fast_path){
    zoom_result = fuzzy_zoom_fast(data,y,bound_index,0);
  }
  else{
    zoom_result=full_zoom(data, y,bound_index,thd_num);
  }
  // focusing
  int m=bound_index.n_rows;
  arma::rowvec focus_result=focusing_fuzzy(data,y,zoom_result,m,fast_path,filter_pval,thd_num);
  return(focus_result);
}
